# Input Monitor

Input Monitor is an on-screen draggable widget that displays keyboard and mouse activity.

## Uses
- Demostrate the use of keyboard shortcuts and mouse actions during presentations or screen recordings.
- Find XY coordinates of mouse cursor
- See current keyboard lock states (Num Lock, Caps Lock, Scroll Lock)
- Find area under mouse drag selection

## Compatibility
Tested on Windows 10/11 and Ubuntu 24.04.

## Installation

```
pip install input-monitor
```

If you don't have Python installed, get the [latest standalone executable](https://github.com/zion-school/input-monitor/releases/latest/download/input-monitor.exe).

## Running the app

```bash
input-monitor
```

or

```bash
python -m input_monitor
```
